@@ -1,4 +1,4 @@
-'''
+r'''
 # cdk-serverless-clamscan
 
 [![npm version](https://badge.fury.io/js/cdk-serverless-clamscan.svg)](https://badge.fury.io/js/cdk-serverless-clamscan)
@@ -183,6 +183,9 @@ See [CONTRIBUTING](./CONTRIBUTING.md) for more information.
 
 This project is licensed under the Apache-2.0 License.
 '''
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
