@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -15,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-serverless-clamscan",
-    "2.6.48",
+    "2.7.8",
     __name__[0:-6],
-    "cdk-serverless-clamscan@2.6.48.jsii.tgz",
+    "cdk-serverless-clamscan@2.7.8.jsii.tgz",
 )
 
 __all__ = [
